@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: Util.py 12122 2020-04-25 14:24:08Z Trista $
+# $Id: Util.py 12123 2020-04-25 14:28:00Z Trista $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Trista $ (last)
-# $Date: 2020-04-25 22:24:08 +0800 (週六, 25 四月 2020) $
-# $Revision: 12122 $
+# $Date: 2020-04-25 22:28:00 +0800 (週六, 25 四月 2020) $
+# $Revision: 12123 $
 """
 Utilities.
 """
@@ -41,7 +41,7 @@ def determinePrintDetail(printDetail, args):
     else:
         printDetail = False
     
-    return PrintDetail
+    return printDetail
 
 def populateEnvToSettings(keys, settingsDict, setter=None, evalKeys=None, printDetail=True):
     """
