@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: App.py 11172 2018-07-16 09:31:00Z Lavender $
+# $Id: App.py 11517 2019-05-03 12:53:40Z Andy $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Lavender $ (last)
-# $Date: 2018-07-16 17:31:00 +0800 (週一, 16 七月 2018) $
-# $Revision: 11172 $
+# $Author: Andy $ (last)
+# $Date: 2019-05-03 20:53:40 +0800 (週五, 03 五月 2019) $
+# $Revision: 11517 $
 
 
  
@@ -38,5 +38,5 @@ else:
     if 'DJANGO_SETTINGS_MODULE' not in os.environ:
         os.environ.setdefault('DJANGO_SETTINGS_MODULE', settings)
 
-    app = Celery(projectName)
+    app = Celery(projectName, strict_typing=False)
     app.config_from_object(settings)
