@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 11172 2018-07-16 09:31:00Z Lavender $
+# $Id: __init__.py 11517 2019-05-03 12:53:40Z Andy $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Lavender $ (last)
-# $Date: 2018-07-16 17:31:00 +0800 (週一, 16 七月 2018) $
-# $Revision: 11172 $
+# $Author: Andy $ (last)
+# $Date: 2019-05-03 20:53:40 +0800 (週五, 03 五月 2019) $
+# $Revision: 11517 $
 
 from celery import Celery
 from Iuno.cloud import tryGet
@@ -39,13 +39,14 @@ def attachSettings(settingsLocals, backends, preferred, config):
                          host=hostInfo.info.host,
                          port=hostInfo.info.port,
                          vHost=hostInfo.info.vhost                         
-                       ),                   
+                       ),   
+        
         
         'CELERY_RESULT_BACKEND': 'redis://:{password}'
                                  '@{host}:{port}'.format(
                                     password=hostInfo.info.redisPassword,
                                     host=hostInfo.info.host,
-                                    port=hostInfo.info.redisPassword
+                                    port='6379'
                                  ),
         'CELERY_TASK_SERIALIZER': 'pickle',
         'CELERY_RESULT_SERIALIZER': 'pickle',
