@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: views.py 11172 2018-07-16 09:31:00Z Lavender $
+# $Id: views.py 11787 2019-12-03 16:12:54Z Lavender $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,10 +12,13 @@
 # limitations under the License.
 #
 # $Author: Lavender $ (last)
-# $Date: 2018-07-16 17:31:00 +0800 (週一, 16 七月 2018) $
-# $Revision: 11172 $
+# $Date: 2019-12-04 00:12:54 +0800 (週三, 04 十二月 2019) $
+# $Revision: 11787 $
+
+from django.conf import settings
 
 from account import views
+from account.forms import LoginEmailForm
 
 
 class SignupView(views.SignupView):
@@ -32,6 +35,12 @@ class LoginView(views.LoginView):
     
     template_name = "member/Login.html"
     template_name_ajax = "member/ajax/Login.html"
+    
+    if hasattr(settings, 'ACCOUNT_USE_EMAIL_LOGIN'):
+        if settings.ACCOUNT_USE_EMAIL_LOGIN:
+            form_class = LoginEmailForm
+            
+        
 
 
 class LogoutView(views.LogoutView):
