@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: start_app.py 11938 2020-02-19 07:52:03Z Lavender $
+# $Id: start_app.py 12039 2020-04-04 08:25:59Z Lavender $
 #
 # Copyright (c) 2016 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2020-02-19 15:52:03 +0800 (週三, 19 二月 2020) $
-# $Revision: 11938 $
+# $Date: 2020-04-04 16:25:59 +0800 (週六, 04 四月 2020) $
+# $Revision: 12039 $
 
 import os
 import sys
@@ -104,13 +104,13 @@ class Command(BaseCommand):
                 if os.path.isdir(filePath):
                     shutil.copytree(filePath, toPath)
                 if os.path.isfile(filePath):
-                    with open(filePath, 'r') as f:
+                    with open(filePath, 'rb') as f:
                         content = f.read()
                     content = utf8(header) + utf8(content)
                     if fileName.startswith("settings"):
-                        content = content + scrapySettings
-                    with open(toPath, 'w') as f:
-                        f.write(content.replace(SCRAPY_PROJECT_NAME, name))
+                        content = content + utf8(str(scrapySettings))
+                    with open(toPath, 'wb') as f:
+                        f.write(content.replace(SCRAPY_PROJECT_NAME.encode(), name.encode()))
 
             with open("REQUIREMENTS.txt", 'r') as f:
                 content = f.read()
