@@ -16,7 +16,7 @@
 # $Revision: 11244 $
 
 import os
-import ConfigParser
+import configparser
 import datetime
 
 from django.core.management.base import BaseCommand, CommandError
@@ -35,18 +35,18 @@ class Command(BaseCommand):
         domain = options['domain']
         
         if os.path.isfile('scrapy.cfg'):
-            config = ConfigParser.ConfigParser()
+            config = configparser.ConfigParser()
             config.read('scrapy.cfg')
             projectName = config.get('deploy', 'project')
             spiderPath = os.path.join(projectName, 'spiders', "%s.py" % name)
             
             if not os.path.isfile(spiderPath):
-                temp = get_template('scaffold/Spider.py')
-                context = Context({
+                temp = get_template('scaffold/Spider.txt')
+                context = {
                     "year": datetime.date.today().year,
                     "name": name,
                     "domain": domain,
-                })
+                }
                 content = temp.render(context)
                 
                 with open(spiderPath, 'w') as f:
