@@ -240,18 +240,19 @@ class BonusRecordManager(models.Manager):
     
     @transaction.atomic
     def createBonusRecord(self, user, order, use=0, receive=0, adjust=0, note=None):
-        record = BonusRecord.objects.create(
-            user=user,
-            order=order,
-            use=use,
-            receive=receive,
-            adjust=adjust,
-            note=note,
-        )
-        
-        # recordUsingBonus
-        self.recordUsingBonus(record)
-        return record
+        if not use == 0 and receive == 0:
+            record = BonusRecord.objects.create(
+                user=user,
+                order=order,
+                use=use,
+                receive=receive,
+                adjust=adjust,
+                note=note,
+            )
+            
+            # recordUsingBonus
+            self.recordUsingBonus(record)
+            return record
    
 class BonusRecord(models.Model):
     user = models.ForeignKey(
@@ -283,7 +284,7 @@ class BonusRecord(models.Model):
     createdTime = models.DateTimeField(_("Created Time"), auto_now_add=True)
     
     expiredTime = models.DateTimeField(_("Expired Time"), null=True)
-    expiredTimeSetting = models.DateTimeField(_("Expired Time Setting"), null=True)
+    expireTimeSetting = models.DateTimeField(_("Expired Time Setting"), null=True)
     
     note = models.TextField(_("Note"), null=True)
     
@@ -294,21 +295,21 @@ class BonusRecord(models.Model):
         return self.receive + self.adjust - self.usedBonus - self.expiredBonus
     
     @property
-    def systemExpiredTime(self):
+    def systemExpireTime(self):
         config = BonusSettings.objects.get()
         return self.createdTime + datetime.timedelta(days=config.expiryDays)
             
     @property
-    def expectedExpiredTime(self):
+    def expectedExpireTime(self):
         if not self.expiredTime:
             config = BonusSettings.objects.get()
             if config.expiryDays >= 0:
-                if not self.expiredTimeSetting:
+                if not self.expireTimeSetting:
                     # 動態產生
                     return self.createdTime + datetime.timedelta(days=config.expiryDays)
                 else:
                     # 固定時間
-                    return self.expiredTimeSetting
+                    return self.expireTimeSetting
             else:
                 # 沒有設定
                 return None
@@ -317,17 +318,17 @@ class BonusRecord(models.Model):
             return self.expiredTime
             
     def updateExpiredBonus(self):
-        if self.expectedExpiredTime:
+        if self.expectedExpireTime:
             # 有過期設定，還沒更新過期
             config = BonusSettings.objects.get()
             b = Bonus.objects.get(user=self.user)
             now = timezone.localtime(timezone.now())
             if config.expiryDays >= 0:
-                if self.expectedExpiredTime <= now and not self.expiredTime: # 還沒紀錄過過期的紀錄
+                if self.expectedExpireTime <= now and not self.expiredTime: # 還沒紀錄過過期的紀錄
                     canUsingBonus = self.canUsingBonus
                     
                     self.expiredBonus = canUsingBonus
-                    self.expiredTime = self.expectedExpiredTime
+                    self.expiredTime = self.expectedExpireTime
                     self.save()
                     
                     if b.quantity - self.expiredBonus >= 0:
